@@ -94,10 +94,13 @@ class ArchiveBase:
                 time.sleep(1)
                 continue
 
-            if len(yet) > 1 and self.multi_read:
+            if self.multi_read:
                 logger.debug("getitems")
                 logger.debug(f"yet = {yet}")
-                file_names, images = self.getitems(yet[0], yet[-1])
+                # read more because self.i is update till calling getitems
+                file_names, images = self.getitems(
+                    yet[0], self.in_range(yet[0] + int(self.next_cache / 2))
+                )
                 logger.debug(f"yet[0], yet[-1] = {yet[0]}, {yet[-1]}")
                 for j, file_name, image in zip(
                     list(range(yet[0], yet[-1] + 1)), file_names, images
@@ -118,7 +121,7 @@ class ArchiveBase:
         self.i = i
 
         if self.cache.get(i) is not None:
-            logger.debug("use cache")
+            logger.debug("cache hit")
             return self.cache[i]
 
         logger.debug(f"cache failed:{i}")
@@ -152,12 +155,14 @@ class ArchiveBase:
         return self[self.i]
 
     def trash(self):
-        logger.debug(self.file_path)
-        if self.file_path is not None:
+        logger.debug("called")
+        file_path = self.file_path
+        self.close()
+        if file_path is not None:
             if "send2trash" not in globals():
                 global send2trash
                 from send2trash import send2trash
-            send2trash(str(self.file_path))
+            send2trash(str(file_path))
 
 
 class DirectoryArchive(ArchiveBase):
@@ -696,6 +701,11 @@ class Config:
 DefaultFitMode = Both
 DefaultFullScreen = True
 
+
+# If you make this value too much, it will occupy too much memory.
+DefaultPrevCache = 4
+DefaultNextCache = 10
+
 # true or false.
 DoublePage = False
 
@@ -780,6 +790,9 @@ Reload      = r
 
             config[row[0].strip()] = row[1].strip()
 
+    def load_from_args(self, key, value):
+        self.settinng[key] = value
+
     def write_default_config(self, file_path):
         if file_path.exists():
             print(f"{file_path} already exists. Not overwerite.")
@@ -790,13 +803,12 @@ Reload      = r
 
 
 class SaltViewer(tk.Tk):
-    def __init__(self, config_path, fullscreen=False):
+    def __init__(self, config_path, args):
         logger.debug("tk.Tk init")
         super().__init__()
 
         self.archive = None
 
-        self.attributes("-fullscreen", fullscreen)
         logger.debug("set title")
         self.title("SaltViewer")
 
@@ -840,7 +852,7 @@ class SaltViewer(tk.Tk):
 
         self.num = 0
 
-        self.load_config()
+        self.load_config(args)
 
     def reload(self, event):
         self.archive.cache = {}
@@ -865,8 +877,13 @@ class SaltViewer(tk.Tk):
         self._change_image_fit_mode("None")
         self.current_page()
 
-    def load_config(self):
+    def load_config(self, args):
         logger.debug("called")
+
+        logger.debug("overwrite settings")
+        for k, v in args.items():
+            self.config.setting[k] = v
+
         for name, key in self.config.keymap.items():
             func = self.binding.get(name)
             if name is None:
@@ -891,6 +908,10 @@ class SaltViewer(tk.Tk):
                 self.image.select_down_scale_algorithm(key)
             elif name == "DefaultFullScreen":
                 self.attributes("-fullscreen", key == "True")
+            elif name == "DefaultPrevCache":
+                ArchiveBase.prev_cache = int(key)
+            elif name == "DefaultNextCache":
+                ArchiveBase.next_cache = int(key)
 
         self.bind("<Escape>", self.reset_num)
         self.bind("[", self.reset_num)
@@ -972,12 +993,15 @@ class SaltViewer(tk.Tk):
             if len(archive) == 1:
                 print("Archive is empty")
                 self.archive.trash()
+                archive.close()
                 self.quit(None)
                 return
             next_file_path = archive.next()[0]
             if next_file_path == file_path:
                 next_file_path = archive.prev()[0]
+            archive.close() 
             self.archive.trash()
+            self.archive.close()
             self.open(next_file_path)
         else:
             print("Cancelled")
@@ -1477,8 +1501,49 @@ def main():
         help="write default configuration to path. salt-viewer --default_config >~/.svrc",
         action="store_true",
     )
-    parser.add_argument("--debug", help="debug mode", action="store_true")
-    parser.add_argument("--fullscreen", help="fullscreen", action="store_true")
+    parser.add_argument(
+        "--debug", help="run as debug mode. All log is printed.", action="store_true"
+    )
+    parser.add_argument(
+        "--fullscreen", help="run as fullscreen mode", action="store_true"
+    )
+    parser.add_argument(
+        "--prev_cache",
+        help="number of previous page cache. Default is %(default)s",
+        type=int,
+        default=4,
+    )
+    parser.add_argument(
+        "--next_cache",
+        help="number of previous page cache. Default is %(default)s",
+        type=int,
+        default=10,
+    )
+    parser.add_argument(
+        "--fit_mode",
+        help="fit_mode. Both, Raw, Width, Height.  Default is %(default)s",
+        default="Both",
+    )
+    parser.add_argument(
+        "--page_order",
+        help="page order in double page mode. right2left or left2right. Default is %(default)s",
+        default="right2left",
+    )
+    parser.add_argument(
+        "--double",
+        help="Double page mode. Default is %(default)s.",
+        action="store_true",
+    )
+    parser.add_argument(
+        "--upscale",
+        help="Upscale algorithm. Nearest, Box, Bilinear, Hamming, Bicubic, Lanczos. Default is %(default)s.",
+        default="Lanczos",
+    )
+    parser.add_argument(
+        "--downscale",
+        help="Downscale algorithm. Nearest, Box, Bilinear, Hamming, Bicubic, Lanczos. Default is %(default)s.",
+        default="Lanczos",
+    )
 
     args = parser.parse_args()
 
@@ -1497,8 +1562,17 @@ def main():
         logger.debug("setLevel DEBUG")
         logger.setLevel(logging.DEBUG)
 
+    sv_args = {
+        "DefaultFitMode": args.fit_mode,
+        "DefaultFullScreen": args.fullscreen,
+        "DefaultPrevCache": args.prev_cache,
+        "DefaultNextCache": args.next_cache,
+        "UpScale": args.upscale,
+        "DownScale": args.downscale,
+    }
+
     logger.debug("SaltViewer Init")
-    sv = SaltViewer(args.config, args.fullscreen)
+    sv = SaltViewer(args.config, sv_args)
     logger.debug("opee args.path")
     sv.open(Path(args.path))
     logger.debug("mainloop")
